==> performance-1.2-sources.jar: hudson/plugins/performance/Messages.java <==
// CHECKSTYLE:OFF

package hudson.plugins.performance;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;

@SuppressWarnings({
    "",
    "PMD"
})
public class Messages {

    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Responding time
     * 
     */
    public static String ProjectAction_RespondingTime() {
        return holder.format("ProjectAction.RespondingTime");
    }

    /**
     * Responding time
     * 
     */
    public static Localizable _ProjectAction_RespondingTime() {
        return new Localizable(holder, "ProjectAction.RespondingTime");
    }

    /**
     * Configure
     * 
     */
    public static String GraphConfigurationDetail_DisplayName() {
        return holder.format("GraphConfigurationDetail.DisplayName");
    }

    /**
     * Configure
     * 
     */
    public static Localizable _GraphConfigurationDetail_DisplayName() {
        return new Localizable(holder, "GraphConfigurationDetail.DisplayName");
    }

    /**
     * Performance
     * 
     */
    public static String Report_DisplayName() {
        return holder.format("Report.DisplayName");
    }

    /**
     * Performance
     * 
     */
    public static Localizable _Report_DisplayName() {
        return new Localizable(holder, "Report.DisplayName");
    }

    /**
     * max
     * 
     */
    public static String ProjectAction_Maximum() {
        return holder.format("ProjectAction.Maximum");
    }

    /**
     * max
     * 
     */
    public static Localizable _ProjectAction_Maximum() {
        return new Localizable(holder, "ProjectAction.Maximum");
    }

    /**
     * average
     * 
     */
    public static String ProjectAction_Average() {
        return holder.format("ProjectAction.Average");
    }

    /**
     * average
     * 
     */
    public static Localizable _ProjectAction_Average() {
        return new Localizable(holder, "ProjectAction.Average");
    }

    /**
     * errors
     * 
     */
    public static String ProjectAction_Errors() {
        return holder.format("ProjectAction.Errors");
    }

    /**
     * errors
     * 
     */
    public static Localizable _ProjectAction_Errors() {
        return new Localizable(holder, "ProjectAction.Errors");
    }

    /**
     * min
     * 
     */
    public static String ProjectAction_Minimum() {
        return holder.format("ProjectAction.Minimum");
    }

    /**
     * min
     * 
     */
    public static Localizable _ProjectAction_Minimum() {
        return new Localizable(holder, "ProjectAction.Minimum");
    }

    /**
     * Percentage of errors
     * 
     */
    public static String ProjectAction_PercentageOfErrors() {
        return holder.format("ProjectAction.PercentageOfErrors");
    }

    /**
     * Percentage of errors
     * 
     */
    public static Localizable _ProjectAction_PercentageOfErrors() {
        return new Localizable(holder, "ProjectAction.PercentageOfErrors");
    }

    /**
     * Publish Performance test result report
     * 
     */
    public static String Publisher_DisplayName() {
        return holder.format("Publisher.DisplayName");
    }

    /**
     * Publish Performance test result report
     * 
     */
    public static Localizable _Publisher_DisplayName() {
        return new Localizable(holder, "Publisher.DisplayName");
    }

    /**
     * Performance Report
     * 
     */
    public static String BuildAction_DisplayName() {
        return holder.format("BuildAction.DisplayName");
    }

    /**
     * Performance Report
     * 
     */
    public static Localizable _BuildAction_DisplayName() {
        return new Localizable(holder, "BuildAction.DisplayName");
    }

    /**
     * Performance Trend
     * 
     */
    public static String ProjectAction_DisplayName() {
        return holder.format("ProjectAction.DisplayName");
    }

    /**
     * Performance Trend
     * 
     */
    public static Localizable _ProjectAction_DisplayName() {
        return new Localizable(holder, "ProjectAction.DisplayName");
    }

}

==> performance-1.3-sources.jar: hudson/plugins/performance/Messages.java <==
// CHECKSTYLE:OFF

package hudson.plugins.performance;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;

@SuppressWarnings({
    "",
    "PMD"
})
public class Messages {

    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Responding time
     * 
     */
    public static String ProjectAction_RespondingTime() {
        return holder.format("ProjectAction.RespondingTime");
    }

    /**
     * Responding time
     * 
     */
    public static Localizable _ProjectAction_RespondingTime() {
        return new Localizable(holder, "ProjectAction.RespondingTime");
    }

    /**
     * Trend report
     * 
     */
    public static String TrendReportDetail_DisplayName() {
        return holder.format("TrendReportDetail.DisplayName");
    }

    /**
     * Trend report
     * 
     */
    public static Localizable _TrendReportDetail_DisplayName() {
        return new Localizable(holder, "TrendReportDetail.DisplayName");
    }

    /**
     * Configure
     * 
     */
    public static String GraphConfigurationDetail_DisplayName() {
        return holder.format("GraphConfigurationDetail.DisplayName");
    }

    /**
     * Configure
     * 
     */
    public static Localizable _GraphConfigurationDetail_DisplayName() {
        return new Localizable(holder, "GraphConfigurationDetail.DisplayName");
    }

    /**
     * Performance
     * 
     */
    public static String Report_DisplayName() {
        return holder.format("Report.DisplayName");
    }

    /**
     * Performance
     * 
     */
    public static Localizable _Report_DisplayName() {
        return new Localizable(holder, "Report.DisplayName");
    }

    /**
     * max
     * 
     */
    public static String ProjectAction_Maximum() {
        return holder.format("ProjectAction.Maximum");
    }

    /**
     * max
     * 
     */
    public static Localizable _ProjectAction_Maximum() {
        return new Localizable(holder, "ProjectAction.Maximum");
    }

    /**
     * average
     * 
     */
    public static String ProjectAction_Average() {
        return holder.format("ProjectAction.Average");
    }

    /**
     * average
     * 
     */
    public static Localizable _ProjectAction_Average() {
        return new Localizable(holder, "ProjectAction.Average");
    }

    /**
     * errors
     * 
     */
    public static String ProjectAction_Errors() {
        return holder.format("ProjectAction.Errors");
    }

    /**
     * errors
     * 
     */
    public static Localizable _ProjectAction_Errors() {
        return new Localizable(holder, "ProjectAction.Errors");
    }

    /**
     * min
     * 
     */
    public static String ProjectAction_Minimum() {
        return holder.format("ProjectAction.Minimum");
    }

    /**
     * min
     * 
     */
    public static Localizable _ProjectAction_Minimum() {
        return new Localizable(holder, "ProjectAction.Minimum");
    }

    /**
     * Percentage of errors
     * 
     */
    public static String ProjectAction_PercentageOfErrors() {
        return holder.format("ProjectAction.PercentageOfErrors");
    }

    /**
     * Percentage of errors
     * 
     */
    public static Localizable _ProjectAction_PercentageOfErrors() {
        return new Localizable(holder, "ProjectAction.PercentageOfErrors");
    }

    /**
     * Publish Performance test result report
     * 
     */
    public static String Publisher_DisplayName() {
        return holder.format("Publisher.DisplayName");
    }

    /**
     * Publish Performance test result report
     * 
     */
    public static Localizable _Publisher_DisplayName() {
        return new Localizable(holder, "Publisher.DisplayName");
    }

    /**
     * Performance Report
     * 
     */
    public static String BuildAction_DisplayName() {
        return holder.format("BuildAction.DisplayName");
    }

    /**
     * Performance Report
     * 
     */
    public static Localizable _BuildAction_DisplayName() {
        return new Localizable(holder, "BuildAction.DisplayName");
    }

    /**
     * Performance Trend
     * 
     */
    public static String ProjectAction_DisplayName() {
        return holder.format("ProjectAction.DisplayName");
    }

    /**
     * Performance Trend
     * 
     */
    public static Localizable _ProjectAction_DisplayName() {
        return new Localizable(holder, "ProjectAction.DisplayName");
    }

}
